@@ -1,23 +1,7 @@
 from dataclasses import dataclass
-from typing import Any, Callable, Generic, TypeVar, Union
+from typing import Any, Callable, Generic, Union
 
-A = TypeVar("A")
-B = TypeVar("B")
-C = TypeVar("C")
-D = TypeVar("D")
-E = TypeVar("E")
-
-__all__ = (
-    "First",
-    "Second",
-    "Third",
-    "Fourth",
-    "Fifth",
-    "Either",
-    "Either3",
-    "Either4",
-    "Either5",
-)
+from koda._generics import A, B, C, D, E
 
 
 @dataclass(frozen=True)
